Enum Insert

pub enum Insert {
    Templates {
        opts: InsertOpts,
        job_template_lists_name: String,
        local_or_remote: LocalOrRemote,
        reference_names: Vec<GitReference>,
    },
    TemplatesOfBranch {
        opts: InsertOpts,
        branch_name: GitBranchName,
        local_or_remote: LocalOrRemote,
        reference_names: Vec<GitReference>,
    },
    Branch {
        opts: InsertOpts,
        local_or_remote: LocalOrRemote,
        branch_name: Option<GitBranchName>,
        more_reference_names: Vec<GitReference>,
    },
    JobFiles {
        opts: InsertOpts,
        force_invalid_opt: ForceInvalidOpt,
        commit: Option<GitHash>,
        paths: Vec<PathBuf>,
    },
}

Variants



Templates

Take template definitions of a given named entry from the configuration file, and commits from explicitly specified references.

Fields

job_template_lists_name: String

The name of the entry in the job_template_lists_name field in the configuration file (RunConfig).

local_or_remote: LocalOrRemote

Whether to look up Git references in the remote repository or in a local clone (in which case the current working dir must be inside it)

reference_names: Vec<GitReference>

Git references to the commits that should be benchmarked (commit ids, branch oder tag names, and other syntax like HEAD^).



TemplatesOfBranch

Take template definitions of a branch name from the configuration file, and commits specified separately (if you want to take the commit from the same branch that you specify, you can use the branch subcommand instead).

Fields

branch_name: GitBranchName
local_or_remote: LocalOrRemote

Whether to look up Git references in the remote repository or in a local clone (in which case the current working dir must be inside it)

reference_names: Vec<GitReference>

Git references to the commits that should be benchmarked (commit ids, branch oder tag names, and other syntax like HEAD^).



Branch

Take template definitions of a branch name from the configuration file. If no branch name is given, takes the currently checked-out branch for ‘local’ or the default branch for ‘remote’. If you just want to take the configuration from a branch, but specify the commit independently, use the template-of-branch subcommand instead.

Fields

local_or_remote: LocalOrRemote

Whether to look up Git references in the remote repository or in a local clone (in which case the current working dir must be inside it)

branch_name: Option<GitBranchName>

Branch name to use for template lookup and commit id. If not given, the currently checked-out branch name is tried (fails if that branch has no template configuration). Be careful when using local mode if your local branch naming conventions differ from the remote ones.

more_reference_names: Vec<GitReference>

Further commits to insert, specified via Git references (commit ids, branch oder tag names, and other syntax like HEAD^).



JobFiles

Take template definitions and commit from job specification files (e.g. to re-use files of failed jobs from queues, or edit manually)

Fields

force_invalid_opt: ForceInvalidOpt
commit: Option<GitHash>

Override the commit id found in the file

paths: Vec<PathBuf>

Path(s) to the JSON file(s) to insert. The format is the one used in the ~/.evobench/queues/ directories, except you can alternatively choose JSON5, RON, or one of the other formats shown in config-formats if the file has a corresponding file extension.

Implementations

Source

impl Insert

pub fn run( self, run_config_bundle: &RunConfigBundle, queues: &RunQueues, ) -> Result<usize>