pub enum LocalOrRemote {
Local,
Remote,
}Expand description
Whether to look up Git references in the remote repository or in a local clone (in which case the current working dir must be inside it)
Variants
Local
Resolve branch names and references in the local repository (fails if the current working directory is not inside a clone of the target project repository)
Remote
Resolve branch names and references in the remote repository
Implementations
Sourceimpl LocalOrRemote
impl LocalOrRemote